Plugins
========

build plugins are ideal for creating generated files

.. automodule:: drain_swamp.monkey.plugins
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: plugins subpackage exports

.. tableofcontents::
